Simple bots or Simbots is a library designed to create simple chat bots using python. 

Its Basic functions :- 
 
1) Uses Machine learning to create Intents . 
2) Supports multiple ways of creating entities and relations . 
3) Also provides helper functions to query context stack .
4) Provides a framework to create text based chatbots .
5) Provides a framework to define test conversation of the bot and test it .
6) Support saving and loading existing conversation .
7) Support saving and loading trained Chatbot .
8) Supports Sub Conversation management and creation .

if you are unfamiliar with any of these terms check out the [documentation](https://vaibhavrr1.github.io/simbots/index.html) .

To install simply use 

    pip install simbots
    
Links
 
 1) [Documentation](https://vaibhavrr1.github.io/simbots/index.html) 
 2) [pypi](https://pypi.org/project/simbots/)
 3) [github](https://github.com/vaibhavrr1/simbots)
 
Check out the [documentation](https://vaibhavrr1.github.io/simbots/index.html) page for chatbot terminology and how to solve some common problems like :


1) How to make simple conversation .
2) Convert site FAQs (Frequently asked questions) to a chatbot .
3) Detect and handle person names from chat texts .
4) Create and Place restaurant orders from chat .


 
 
 